<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" class="evenly-distributed-labels" :inline="true" v-show="showSearch"
      label-width="80px" label-position="left">
      <el-form-item label="计划名称" prop="companyName">
        <el-input v-model="queryParams.planName" placeholder="请输入计划名称" clearable style="width: 200px"
          @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="计划编号" prop="companyCode">
        <el-input v-model="queryParams.planNo" placeholder="请输入计划编号" clearable style="width: 200px"
          @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="执法单位" prop="companyUser">
        <el-input v-model="queryParams.companyUser" placeholder="请输入执法单位" clearable style="width: 200px"
          @keyup.enter="handleQuery" />
      </el-form-item>
      <el-form-item label="执法时间" style="width: 290px">
        <el-date-picker v-model="dateRange" value-format="YYYY-MM-DD" type="daterange" range-separator="-"
          start-placeholder="开始日期" end-placeholder="结束日期"></el-date-picker>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
        <el-button icon="Refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="Plus" @click="handleAdd()" v-hasPermi="['system:dept:add']">新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="primary" plain icon="Upload" @click="exportExcel"
          v-hasPermi="['system:dept:add']">导入</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="primary" plain icon="Download" @click="downLoadCode">导出</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="primary" plain icon="Download" @click="downLoadCode">发起综合查一次</el-button>
      </el-col>
    </el-row>

    <el-table v-if="refreshTable" v-loading="loading" :data="deptList" row-key="companyId"
      :default-expand-all="isExpandAll" :tree-props="{ children: 'children', hasChildren: 'hasChildren' }"
      @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column prop="planNo" label="计划编号" width="180"></el-table-column>
      <el-table-column prop="planName" label="计划名称" width="180"></el-table-column>
      <el-table-column prop="makeOrgName" label="制定机构" width="180"></el-table-column>
      <el-table-column prop="checkdObject" label="被检查对象" width="180"></el-table-column>
      <el-table-column prop="unifiedSocialCreditCode" label="统一社会信用代码" width="180"></el-table-column>
      <el-table-column prop="industry" label="所属行业" width="180"></el-table-column>
      <el-table-column prop="checkdType" label="检查方式" width="180"></el-table-column>
      <el-table-column prop="checkdContent" label="检查内容" width="180"></el-table-column>
      <el-table-column prop="executiveSection" label="执行科室" width="180"></el-table-column>
      <el-table-column prop="planFrequency" label="计划频次" width="180"></el-table-column>
      <el-table-column prop="planMonth" label="计划月份" width="180"></el-table-column>
      <el-table-column prop="planStatus" label="状态" width="180"></el-table-column>
      <el-table-column label="操作" align="center" fixed="right" class-name="small-padding fixed-width" width="240">
        <template #default="scope">
          <el-link type="info" @click="createQrcodeHandler(scope.row)">查看</el-link>
          <el-divider direction="vertical" />
          <el-link type="primary" @click="handleAdd(scope.row)">编辑</el-link>
          <el-divider direction="vertical" />
          <el-link type="error" @click="handleDelete(scope.row)">删除</el-link>
        </template>
      </el-table-column>
    </el-table>
    <pagination v-show="queryParams.total > 0" :total="queryParams.total" v-model:page="queryParams.pageNum"
      v-model:limit="queryParams.pageSize" @pagination="getList" />

    <!-- 添加或修改对话框 -->
    <el-dialog :title="title" v-model="open" width="700px" append-to-body>
      <el-form ref="deptRef" :model="form" :rules="rules" label-width="140px">
        <el-row :gutter="20">
          <el-col :span="12">
            <el-form-item label="计划名称" prop="planName">
              <el-input v-model="form.planName" placeholder="请输入计划名称" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="制定计划的机构" prop="makeOrgName">
              <el-input v-model="form.makeOrgName" placeholder="请输入制定计划的机构" />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="20">
          <el-col :span="12">
            <el-form-item label="被检查的对象" prop="checkdObject">
              <el-input v-model="form.checkdObject" placeholder="请输入被检查的对象" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="统一社会信用代码" prop="unifiedSocialCreditCode">
              <el-input v-model="form.unifiedSocialCreditCode" placeholder="请输入统一社会信用代码" />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="20">
          <el-col :span="12">
            <el-form-item label="行业" prop="industry">
              <el-input v-model="form.industry" placeholder="请输入行业" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="执行科室" prop="executiveSection">
              <el-input v-model="form.executiveSection" placeholder="请输入执行科室" />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="20">
          <el-col :span="24">
            <el-form-item label="检查内容" prop="checkdContent">
              <el-input v-model="form.checkdContent" type="textarea" placeholder="请输入检查内容" />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="20">
          <el-col :span="12">
            <el-form-item label="计划频率" prop="planFrequency">
              <el-input v-model="form.planFrequency" placeholder="请输入计划频率" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="计划月份" prop="planMonth">
              <el-input v-model="form.planMonth" placeholder="请输入计划月份" />
            </el-form-item>
          </el-col>
        </el-row>
        <!-- <el-form-item label="状态">
          <el-switch v-model="form.companyStatus" :active-value="0" :inactive-value="1"></el-switch>
        </el-form-item> -->
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
    <exportExcelCom ref="exporttem" @resList="resList"></exportExcelCom>
    <exportRecord ref="exportRecordCom" :recordRow="recordRow" @uploadList="getList"></exportRecord>
    <judgeCom ref="judgeComRef" @upload="getList"></judgeCom>
    <createQrcode ref="createQrcodeRef"></createQrcode>
  </div>
</template>

<script setup name="Dept">
// import FileUpload from '@/components/ImageUpload/index'
// import exportRecord from './components/exportRecord'
// import createQrcode from './components/createQrcode'
// import judgeCom from './components/judge'
import { listCompany, addCompany, updStatus, delCompany, updateCompany, getCompany } from "@/api/system/company/company";
// import exportExcelCom from './components/export'
import { listManage } from "@/api/system/manage";
import { computed } from "vue";
import { judgeStatus, companyStatus, scopeList } from '@/utils/mapList/index.ts'
import useSettingsStore from "@/store/modules/settings";
import { download } from '@/utils/request'; // 下载文件
const thcolor = computed(() => useSettingsStore().theme);
const { proxy } = getCurrentInstance();
const { sys_normal_disable } = proxy.useDict("sys_normal_disable");
const deptList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const title = ref("");
const deptOptions = ref([]);
const isExpandAll = ref(false);
const refreshTable = ref(true);
const exporttem = ref()
const exportRecordCom = ref()
const judgeComRef = ref()
const createQrcodeRef = ref()
const options = reactive({
  companyStatus: [
    {
      label: '正常',
      value: 0
    },
    {
      label: '禁用',
      value: 1
    },
  ],
})
const data = reactive({
  form: {},
  queryParams: {
    planNo: '',
    planName: '',
    value1: '',
    pageNum: 1,
    pageSize: 10,
    total: 1
  },
  rules: {
    planName: [{ required: true, message: "计划名称不能为空", trigger: "blur" }],
    makeOrgName: [{ required: true, message: "制定计划的机构不能为空", trigger: "blur" }],
    checkdObject: [{ required: true, message: "被检查对象不能为空", trigger: "blur" }],
    unifiedSocialCreditCode: [{ required: true, message: "统一社会信用代码不能为空", trigger: "blur" }],
    industry: [{ required: true, message: "所属行业不能为空", trigger: "blur" }],
    checkdContent: [{ required: true, message: "检查内容不能为空", trigger: "blur" }],
    executiveSection: [{ required: true, message: "执行科室不能为空", trigger: "blur" }],
    planFrequency: [{ required: true, message: "计划频次不能为空", trigger: "blur" }],
    planMonth: [{ required: true, message: "计划月份不能为空", trigger: "blur" }],
  },
});

const { queryParams, form, rules } = toRefs(data);
const recordRow = ref([])
/** 查询企业列表 */
function getList() {
  loading.value = true;
  listManage(queryParams.value).then((response) => {
    deptList.value = response.rows
    data.queryParams.total = response.total
    loading.value = false;
  });
}
/** 取消按钮 */
function cancel() {
  open.value = false;
  reset();
  getList();
}
/** 表单重置 */
function reset() {
  form.value = {
    planName: '', // 计划名称
    makeOrgName: '', // 制定机构
    checkdObject: '', // 被检查对象
    unifiedSocialCreditCode: '', // 统一社会信用代码
    industry: '', // 所属行业
    checkdContent: '', // 检查内容
    executiveSection: '', // 执行科室
    planFrequency: '', // 计划频次
    planMonth: '', // 计划月份
  };
  proxy.resetForm("deptRef");
}
const queryRef = ref()
/** 搜索按钮操作 */
function handleQuery() {
  getList();
}
/** 重置按钮操作 */
function resetQuery() {
  queryRef.value.resetFields();
  handleQuery();
}
function getDetails(id) {
  getCompany(id).then((response) => {
    form.value = response.data;
    open.value = true;
    // title.value = "查看企业";
  });
}
/** 新增按钮操作 */
function handleAdd(row) {
  if (row) {
    // form.value = row
    title.value = "编辑计划";
    getDetails(row.companyId)
  } else {
    form.value = {
      companyStatus: 0
    }
    title.value = "添加计划";
    open.value = true;
  }
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["deptRef"].validate((valid) => {
    if (valid) {
      if (form.value.companyId != undefined) {
        updateCompany(form.value).then((response) => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addCompany(form.value).then((response) => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}
/** 删除按钮操作 */
function handleDelete(row) {
  proxy.$modal
    .confirm('是否确认删除该数据?')
    .then(function () {
      return delCompany({ delId: row.companyId });
    })
    .then(() => {
      getList();
      proxy.$modal.msgSuccess("删除成功");
    })
    .catch(() => { });
}
// 修改企业信息
function changeCompanyNews(row, event) {
  if (loading.value) {
    return
  }
  updStatus(row).then(val => {
    proxy.$modal.msgSuccess("修改成功");
    getList();
  })
}
// 导入模板
function exportExcel() {
  exporttem.value.openDialog()
}
// 导入记录
function exportRecordComOpen() {
  exportRecordCom.value.openDialog()
}
function resList(row) {
  recordRow.value = row
  exportRecordCom.value.openDialog()
}
function checkJudge(row) {
  judgeComRef.value.openDialog(row)
}
function createQrcodeHandler(row) {
  createQrcodeRef.value.openDialog(row)
}
let valueArr = []
function downLoadCode() {
  download('/system/company/downloadQrcode', {
    companyIds: valueArr.join()
  }, "企业图片.zip")
}
function handleSelectionChange(e) {
  console.log(e)
  valueArr = e.map(item => item.companyId)
}
getList();
function selectableFun(e) {
  console.log(e)
}
</script>

<style scoped lang="scss">
.evenly-distributed-labels {
  :deep() {
    .el-form-item__label {
      position: relative;
      /* 设置相对定位作为星号的定位基准 */
      text-align: justify;
      text-align-last: justify;
      /* 确保最后一行也两端对齐 */
      padding-left: 10px;
      /* 为星号预留空间 */
      display: inline-block;
    }
  }
}
</style>
